//%START program
import nsrunit; unit conversion on;

math Comp2Flow {

//%START program
 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=30; t.delta=0.1;

 // PARAMETERS
 real Fp    = 1 ml/(g*min),         // Plasma flow per gram of tissue
      Vp    = 0.05 ml/g,            // Plasma volume per gram of tissue
      Visf  = 0.15 ml/g,            // ISF volume per gram of tissue
      PSc   = 1 ml/(g*min),         // Capillary wall permeability
                                    //   surface area product. The "c" in
                                    //   "PSc" stands stands for cleft, the
                                    //   gap between endothelial cells
      Cp0   = 0 mM,                 // Initial concentration in plasma space
      Cisf0 = 0 mM;                 // Initial concentration in ISF space

 extern real Cin(t) mM;             // Inflowing concentration in plasma

 // VARIABLES
 real Cp(t) mM,                     // Concentration in plasma space
      Cisf(t) mM,                   // Concentration in ISF space
      Cout(t) mM;                   // Outflow concentration, Cout = Cp.

 // INITIAL CONDITIONS
 when(t=t.min) {Cp = Cp0; Cisf = Cisf0; }

 // ORDINARY DIFFERENTIAL EQUATIONS
 Cp:t   = (Fp/Vp)*(Cin-Cp) + (PSc/Vp)*(Cisf-Cp);
 Cisf:t = (PSc/Visf)*(Cp-Cisf);
 Cout   = Cp;

 //Additional Calculations
 real Q(t) nmol/g,
      Qintegral(t) nmol/g;

 when (t=t.min) {Qintegral=Vp*Cp0+Visf*Cisf0;}
 Q=Vp*Cp+Visf*Cisf;
 Qintegral:t=Fp*(Cin-Cout);

 }
//%END program
