import nsrunit; unit conversion on;
 math VascularOperator {

 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=25; t.delta=0.1;
 // Flow parameters
 real FP1(t) L/min, TinjP1=0.5 sec, InjRateP1=8 mg/sec,
      CinP1(t) mg/L, VP1=250 ml, FbarP1 = 45 ml/sec;
 
 CinP1 = if(t<TinjP1) InjRateP1/FbarP1 else 0;
 real KP1=0.5 dimensionless;
 real wP1 sec^(-1);
 real nP1 = 1 sec^(-1);
 real wP1 = 2*PI * nP1;
 real phiP1 = 0;
 FP1=FbarP1*(1+KP1*sin(wP1*t+phiP1));
 // PARAMETERS
 real C0P1     = 0 mg/L,                 // initial concentration
      totalDelayP1 = 5.55555 sec,            // total transit time required
      RDP1     = 0.28 dimensionless,    // Relative dispersion
      RD4thP1 dimensionless,           // RDP1 of a 4th order operator
      zeta1P1 = 0.95 dimensionless,    // 1st 2nd order op damping
      zeta2P1 = 0.80 dimensionless,    // 2nd 2nd order op damping
      wratioP1 = 1.82 dimensionless,   // wratioP1 = w2P1/w1P1
      Zeta1P1 dimensionless;           // protects bad values of zeta1P1
                                     
 //extern real CinP1(t) mM;               // Input concentration
 real CoutP1(t) mg/L;                     // Output Concentration
 // CALCULATED PARAMETERS AND VARIABLES
 real rdP1 dimensionless,            // Enforces 0<=RDP1<=RD4thP1
      pureDelayP1 sec,               // the pure delay  transit time
      op4DelayP1 sec,                // 4th order operator transit time
      w1P1(t) sec^(-1),                 // 1st 2nd order op frequency
      w2P1(t) sec^(-1),                 // 2nd 2nd order op frequency
      CdelayP1(t) mg/L,                // output of pure delay operator
     
      C1P1(t) mg/L, dC1dtP1(t) mg/L/sec,   // 1st 2nd op variables
      C2P1(t) mg/L, dC2dtP1(t) mg/L/sec,   // 2nd 2nd op variables
      C3P1(t) mg/L, dC3dtP1(t) mg/L/sec,   // 3rd 2nd op variables
      C4P1(t) mg/L, dC4dtP1(t) mg/L/sec,   // 4th 2nd op variables
      C5P1(t) mg/L, dC5dtP1(t) mg/L/sec,   // 5th 2nd op variables
      C6P1(t) mg/L, dC6dtP1(t) mg/L/sec;   // 6th 2nd op variables
 // CALCULATIONS
 // Numeric Protection if z1 severely underdamped
 Zeta1P1= /* if(zeta1P1^2 < (wratioP1^2+1)/(2*wratioP1^2) )
        sqrt( (wratioP1^2+1)/(2*wratioP1^2) ) else  */ zeta1P1;
 RD4thP1 = sqrt(3)*sqrt(zeta2P1^2-1/2 + wratioP1^2*(Zeta1P1^2-1/2) )/(zeta2P1 + Zeta1P1*wratioP1);  //Eq. 12
 rdP1 = if (RDP1<0) 0                           // Enforce 0<=RDP1<=RD4thP1
      else if (RDP1>RD4thP1) RD4thP1 
      else RDP1;
 op4DelayP1 = if(3*RDP1/RD4thP1<1) (3*RDP1/RD4thP1)*totalDelayP1 else totalDelayP1;           // Calculate op4 transit time      Eq. 5     
 pureDelayP1 = totalDelayP1-op4DelayP1;            // Calculate pure delay            Eq. 6
// w1P1 =if (op4DelayP1>0) (2/(op4DelayP1/3))*(Zeta1P1+zeta2P1/wratioP1) else 0;  
 w1P1=2*PI*(7.054317592)*FP1/VP1;              //Eq. 11
 w2P1 = w1P1*wratioP1;
 // INITIAL CONDITIONS
 when (t=t.min) {C1P1=0; dC1dtP1=0; C2P1=0; dC2dtP1=0;
                 C3P1=0; dC3dtP1=0; C4P1=0; dC4dtP1=0;
                 C5P1=0; dC5dtP1=0; C6P1=0; dC6dtP1=0; }
 // PURE DELAY AND ODE CALCULATIONS
 CdelayP1 = if(t<=t.min+pureDelayP1) C0P1  
          else CinP1(t-t.min-pureDelayP1);       // Calculate delayed output
 C1P1:t = dC1dtP1;
 dC1dtP1:t = -2*Zeta1P1*w1P1*dC1dtP1 +w1P1^2*(CdelayP1-C1P1);  
 C2P1:t = dC2dtP1;
 dC2dtP1:t = -2*zeta2P1*w2P1*dC2dtP1 + w2P1^2*(C1P1-C2P1);     
 C3P1:t = dC3dtP1;
 dC3dtP1:t = -2*Zeta1P1*w1P1*dC3dtP1 +w1P1^2*(C2P1-C3P1);  
 C4P1:t = dC4dtP1;
 dC4dtP1:t = -2*zeta2P1*w2P1*dC4dtP1 + w2P1^2*(C3P1-C4P1);     
 C5P1:t = dC5dtP1;
 dC5dtP1:t = -2*Zeta1P1*w1P1*dC5dtP1 + w1P1^2*(C4P1-C5P1);  
 C6P1:t = dC6dtP1;
 dC6dtP1:t = -2*zeta2P1*w2P1*dC6dtP1 + w2P1^2*(C5P1-C6P1);     
 // SELECT OUTPUT FROM EITHER DELAY OR 4th op
 CoutP1 = if (op4DelayP1>0) C6P1 else CdelayP1;
 // CALCULATE ALL STATISTICS FROM CinP1 and CoutP1
 real aI mg/L*sec, tI sec, RDI dimensionless,     // CinP1  area, transit time, and RDP1
      skewI dimensionless, kurtI dimensionless, // CinP1  skewness and kurtosis
      aO mg/L*sec, tO sec, RDO dimensionless,     // CoutP1 area, transit time, and RDP1
      skewO dimensionless, kurtO dimensionless, // CoutP1 skewness and kurtosis
      tsys sec, RDsys dimensionless;            // System transit time and RDP1
 curvesStatistics(Cin@t,Cout@t, aI,tI,RDI,skewI,kurtI,
                                aO,tO,RDO,skewO,kurtO,
                                tsys,RDsys);
// This MML file generated from list.mpc using MPC.
