import nsrunit; unit conversion on;
 math VascularOperator {

 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=25; t.delta=0.1;
 // Flow parameters
 real FP2(t) L/min, TinjP2=0.5 sec, InjRateP2=8 mg/sec,
      CinP2(t) mg/L, VP2=250 ml, FbarP2 = 45 ml/sec;
 
 CinP2 = if(t<TinjP2) InjRateP2/FbarP2 else 0;
 real KP2=0.5 dimensionless;
 real wP2 sec^(-1);
 real nP2 = 1 sec^(-1);
 real wP2 = 2*PI * nP2;
 real phiP2 = 0;
 FP2=FbarP2*(1+KP2*sin(wP2*t+phiP2));
 // PARAMETERS
 real C0P2     = 0 mg/L,                 // initial concentration
      totalDelayP2 = 5.55555 sec,            // total transit time required
      RDP2     = 0.28 dimensionless,    // Relative dispersion
      RD4thP2 dimensionless,           // RDP2 of a 4th order operator
      zeta1P2 = 0.95 dimensionless,    // 1st 2nd order op damping
      zeta2P2 = 0.80 dimensionless,    // 2nd 2nd order op damping
      wratioP2 = 1.82 dimensionless,   // wratioP2 = w2P2/w1P2
      Zeta1P2 dimensionless;           // protects bad values of zeta1P2
                                     
 //extern real CinP2(t) mM;               // Input concentration
 real CoutP2(t) mg/L;                     // Output Concentration
 // CALCULATED PARAMETERS AND VARIABLES
 real rdP2 dimensionless,            // Enforces 0<=RDP2<=RD4thP2
      pureDelayP2 sec,               // the pure delay  transit time
      op4DelayP2 sec,                // 4th order operator transit time
      w1P2(t) sec^(-1),                 // 1st 2nd order op frequency
      w2P2(t) sec^(-1),                 // 2nd 2nd order op frequency
      CdelayP2(t) mg/L,                // output of pure delay operator
     
      C1P2(t) mg/L, dC1dtP2(t) mg/L/sec,   // 1st 2nd op variables
      C2P2(t) mg/L, dC2dtP2(t) mg/L/sec,   // 2nd 2nd op variables
      C3P2(t) mg/L, dC3dtP2(t) mg/L/sec,   // 3rd 2nd op variables
      C4P2(t) mg/L, dC4dtP2(t) mg/L/sec,   // 4th 2nd op variables
      C5P2(t) mg/L, dC5dtP2(t) mg/L/sec,   // 5th 2nd op variables
      C6P2(t) mg/L, dC6dtP2(t) mg/L/sec;   // 6th 2nd op variables
 // CALCULATIONS
 // Numeric Protection if z1 severely underdamped
 Zeta1P2= /* if(zeta1P2^2 < (wratioP2^2+1)/(2*wratioP2^2) )
        sqrt( (wratioP2^2+1)/(2*wratioP2^2) ) else  */ zeta1P2;
 RD4thP2 = sqrt(3)*sqrt(zeta2P2^2-1/2 + wratioP2^2*(Zeta1P2^2-1/2) )/(zeta2P2 + Zeta1P2*wratioP2);  //Eq. 12
 rdP2 = if (RDP2<0) 0                           // Enforce 0<=RDP2<=RD4thP2
      else if (RDP2>RD4thP2) RD4thP2 
      else RDP2;
 op4DelayP2 = if(3*RDP2/RD4thP2<1) (3*RDP2/RD4thP2)*totalDelayP2 else totalDelayP2;           // Calculate op4 transit time      Eq. 5     
 pureDelayP2 = totalDelayP2-op4DelayP2;            // Calculate pure delay            Eq. 6
// w1P2 =if (op4DelayP2>0) (2/(op4DelayP2/3))*(Zeta1P2+zeta2P2/wratioP2) else 0;  
 w1P2=2*PI*(7.054317592)*FP2/VP2;              //Eq. 11
 w2P2 = w1P2*wratioP2;
 // INITIAL CONDITIONS
 when (t=t.min) {C1P2=0; dC1dtP2=0; C2P2=0; dC2dtP2=0;
                 C3P2=0; dC3dtP2=0; C4P2=0; dC4dtP2=0;
                 C5P2=0; dC5dtP2=0; C6P2=0; dC6dtP2=0; }
 // PURE DELAY AND ODE CALCULATIONS
 CdelayP2 = if(t<=t.min+pureDelayP2) C0P2  
          else CinP2(t-t.min-pureDelayP2);       // Calculate delayed output
 C1P2:t = dC1dtP2;
 dC1dtP2:t = -2*Zeta1P2*w1P2*dC1dtP2 +w1P2^2*(CdelayP2-C1P2);  
 C2P2:t = dC2dtP2;
 dC2dtP2:t = -2*zeta2P2*w2P2*dC2dtP2 + w2P2^2*(C1P2-C2P2);     
 C3P2:t = dC3dtP2;
 dC3dtP2:t = -2*Zeta1P2*w1P2*dC3dtP2 +w1P2^2*(C2P2-C3P2);  
 C4P2:t = dC4dtP2;
 dC4dtP2:t = -2*zeta2P2*w2P2*dC4dtP2 + w2P2^2*(C3P2-C4P2);     
 C5P2:t = dC5dtP2;
 dC5dtP2:t = -2*Zeta1P2*w1P2*dC5dtP2 + w1P2^2*(C4P2-C5P2);  
 C6P2:t = dC6dtP2;
 dC6dtP2:t = -2*zeta2P2*w2P2*dC6dtP2 + w2P2^2*(C5P2-C6P2);     
 // SELECT OUTPUT FROM EITHER DELAY OR 4th op
 CoutP2 = if (op4DelayP2>0) C6P2 else CdelayP2;
 // CALCULATE ALL STATISTICS FROM CinP2 and CoutP2
 real aI mg/L*sec, tI sec, RDI dimensionless,     // CinP2  area, transit time, and RDP2
      skewI dimensionless, kurtI dimensionless, // CinP2  skewness and kurtosis
      aO mg/L*sec, tO sec, RDO dimensionless,     // CoutP2 area, transit time, and RDP2
      skewO dimensionless, kurtO dimensionless, // CoutP2 skewness and kurtosis
      tsys sec, RDsys dimensionless;            // System transit time and RDP2
 curvesStatistics(Cin@t,Cout@t, aI,tI,RDI,skewI,kurtI,
                                aO,tO,RDO,skewO,kurtO,
                                tsys,RDsys);
// This MML file generated from list.mpc using MPC.
