import nsrunit; unit conversion on;

math Comp2Flow {

 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=30; t.delta=0.1;
 // PARAMETERS
 real PXFpSX    = 1 ml/(g*min),         // Plasma flow per gram of tissue
      PXVpSX    = 0.05 ml/g,            // Plasma volume per gram of tissue
      PXVisfSX  = 0.15 ml/g,            // ISF volume per gram of tissue
      PXPScSX   = 1 ml/(g*min),         // Capillary wall permeability
                                    //   surface area product. The "c" in
                                    //   "PXPScSX" stands stands for cleft, the
                                    //   gap between endothelial cells
      PXCp0SX   = 0 mM,                 // Initial concentration in plasma space
      PXCisf0SX = 0 mM;                 // Initial concentration in ISF space
 extern real PXCinSX(t) mM;             // Inflowing concentration in plasma
 // VARIABLES
 real PXCpSX(t) mM,                     // Concentration in plasma space
      PXCisfSX(t) mM,                   // Concentration in ISF space
      PXCoutSX(t) mM;                   // Outflow concentration, PXCoutSX = PXCpSX.
 // INITIAL CONDITIONS
 when(t=t.min) {PXCpSX = PXCp0SX; PXCisfSX = PXCisf0SX; }
 // ORDINARY DIFFERENTIAL EQUATIONS
 PXCpSX:t   = (PXFpSX/PXVpSX)*(PXCinSX-PXCpSX) + (PXPScSX/PXVpSX)*(PXCisfSX-PXCpSX);
 PXCisfSX:t = (PXPScSX/PXVisfSX)*(PXCpSX-PXCisfSX);
 PXCoutSX   = PXCpSX;
 //Additional Calculations
 real PXQSX(t) nmol/g,
      PXQintegralSX(t) nmol/g;
 when (t=t.min) {PXQintegralSX=PXVpSX*PXCp0SX+PXVisfSX*PXCisf0SX;}
 PXQSX=PXVpSX*PXCpSX+PXVisfSX*PXCisfSX;
 PXQintegralSX:t=PXFpSX*(PXCinSX-PXCoutSX);
 }
// This MML file generated from ChangeList.mpc using MPC.
