import nsrunit; unit conversion on;
 math VascularOperator {

 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=25; t.delta=0.1;
 // Flow parameters
 real preFsuf(t) L/min, preTinjsuf=0.5 sec, preInjRatesuf=8 mg/sec,
      preCinsuf(t) mg/L, preVsuf=250 ml, preFbarsuf = 45 ml/sec;
 
 preCinsuf = if(t<preTinjsuf) preInjRatesuf/preFbarsuf else 0;
 real preKsuf=0.5 dimensionless;
 real prewsuf sec^(-1);
 real prensuf = 1 sec^(-1);
 real prewsuf = 2*PI * prensuf;
 real prephisuf = 0;
 preFsuf=preFbarsuf*(1+preKsuf*sin(prewsuf*t+prephisuf));
 // PARAMETERS
 real preC0suf     = 0 mg/L,                 // initial concentration
      pretotalDelaysuf = 5.55555 sec,            // total transit time required
      preRDsuf     = 0.28 dimensionless,    // Relative dispersion
      preRD4thsuf dimensionless,           // preRDsuf of a 4th order operator
      prezeta1suf = 0.95 dimensionless,    // 1st 2nd order op damping
      prezeta2suf = 0.80 dimensionless,    // 2nd 2nd order op damping
      prewratiosuf = 1.82 dimensionless,   // prewratiosuf = prew2suf/prew1suf
      preZeta1suf dimensionless;           // protects bad values of prezeta1suf
                                     
 //extern real preCinsuf(t) mM;               // Input concentration
 real preCoutsuf(t) mg/L;                     // Output Concentration
 // CALCULATED PARAMETERS AND VARIABLES
 real prerdsuf dimensionless,            // Enforces 0<=preRDsuf<=preRD4thsuf
      prepureDelaysuf sec,               // the pure delay  transit time
      preop4Delaysuf sec,                // 4th order operator transit time
      prew1suf(t) sec^(-1),                 // 1st 2nd order op frequency
      prew2suf(t) sec^(-1),                 // 2nd 2nd order op frequency
      preCdelaysuf(t) mg/L,                // output of pure delay operator
     
      preC1suf(t) mg/L, predC1dtsuf(t) mg/L/sec,   // 1st 2nd op variables
      preC2suf(t) mg/L, predC2dtsuf(t) mg/L/sec,   // 2nd 2nd op variables
      preC3suf(t) mg/L, predC3dtsuf(t) mg/L/sec,   // 3rd 2nd op variables
      preC4suf(t) mg/L, predC4dtsuf(t) mg/L/sec,   // 4th 2nd op variables
      preC5suf(t) mg/L, predC5dtsuf(t) mg/L/sec,   // 5th 2nd op variables
      preC6suf(t) mg/L, predC6dtsuf(t) mg/L/sec;   // 6th 2nd op variables
 // CALCULATIONS
 // Numeric Protection if z1 severely underdamped
 preZeta1suf= /* if(prezeta1suf^2 < (prewratiosuf^2+1)/(2*prewratiosuf^2) )
        sqrt( (prewratiosuf^2+1)/(2*prewratiosuf^2) ) else  */ prezeta1suf;
 preRD4thsuf = sqrt(3)*sqrt(prezeta2suf^2-1/2 + prewratiosuf^2*(preZeta1suf^2-1/2) )/(prezeta2suf + preZeta1suf*prewratiosuf);  //Eq. 12
 prerdsuf = if (preRDsuf<0) 0                           // Enforce 0<=preRDsuf<=preRD4thsuf
      else if (preRDsuf>preRD4thsuf) preRD4thsuf 
      else preRDsuf;
 preop4Delaysuf = if(3*preRDsuf/preRD4thsuf<1) (3*preRDsuf/preRD4thsuf)*pretotalDelaysuf else pretotalDelaysuf;           // Calculate op4 transit time      Eq. 5     
 prepureDelaysuf = pretotalDelaysuf-preop4Delaysuf;            // Calculate pure delay            Eq. 6
// prew1suf =if (preop4Delaysuf>0) (2/(preop4Delaysuf/3))*(preZeta1suf+prezeta2suf/prewratiosuf) else 0;  
 prew1suf=2*PI*(7.054317592)*preFsuf/preVsuf;              //Eq. 11
 prew2suf = prew1suf*prewratiosuf;
 // INITIAL CONDITIONS
 when (t=t.min) {preC1suf=0; predC1dtsuf=0; preC2suf=0; predC2dtsuf=0;
                 preC3suf=0; predC3dtsuf=0; preC4suf=0; predC4dtsuf=0;
                 preC5suf=0; predC5dtsuf=0; preC6suf=0; predC6dtsuf=0; }
 // PURE DELAY AND ODE CALCULATIONS
 preCdelaysuf = if(t<=t.min+prepureDelaysuf) preC0suf  
          else preCinsuf(t-t.min-prepureDelaysuf);       // Calculate delayed output
 preC1suf:t = predC1dtsuf;
 predC1dtsuf:t = -2*preZeta1suf*prew1suf*predC1dtsuf +prew1suf^2*(preCdelaysuf-preC1suf);  
 preC2suf:t = predC2dtsuf;
 predC2dtsuf:t = -2*prezeta2suf*prew2suf*predC2dtsuf + prew2suf^2*(preC1suf-preC2suf);     
 preC3suf:t = predC3dtsuf;
 predC3dtsuf:t = -2*preZeta1suf*prew1suf*predC3dtsuf +prew1suf^2*(preC2suf-preC3suf);  
 preC4suf:t = predC4dtsuf;
 predC4dtsuf:t = -2*prezeta2suf*prew2suf*predC4dtsuf + prew2suf^2*(preC3suf-preC4suf);     
 preC5suf:t = predC5dtsuf;
 predC5dtsuf:t = -2*preZeta1suf*prew1suf*predC5dtsuf + prew1suf^2*(preC4suf-preC5suf);  
 preC6suf:t = predC6dtsuf;
 predC6dtsuf:t = -2*prezeta2suf*prew2suf*predC6dtsuf + prew2suf^2*(preC5suf-preC6suf);     
 // SELECT OUTPUT FROM EITHER DELAY OR 4th op
 preCoutsuf = if (preop4Delaysuf>0) preC6suf else preCdelaysuf;
 // CALCULATE ALL STATISTICS FROM preCinsuf and preCoutsuf
 real aI mg/L*sec, tI sec, RDI dimensionless,     // preCinsuf  area, transit time, and preRDsuf
      skewI dimensionless, kurtI dimensionless, // preCinsuf  skewness and kurtosis
      aO mg/L*sec, tO sec, RDO dimensionless,     // preCoutsuf area, transit time, and preRDsuf
      skewO dimensionless, kurtO dimensionless, // preCoutsuf skewness and kurtosis
      tsys sec, RDsys dimensionless;            // System transit time and preRDsuf
 curvesStatistics(Cin@t,Cout@t, aI,tI,RDI,skewI,kurtI,
                                aO,tO,RDO,skewO,kurtO,
                                tsys,RDsys);
// This MML file generated from list.mpc using MPC.
