import nsrunit; unit conversion on;
math transport4species {
realDomain t s; t.min=0; t.max=120; t.delta=.1;
// PARAMETERS
extern real hA1in(t);
extern real hB1in(t);
extern real cA1in(t);
extern real cB1in(t);
real Fp = 1 ml/(g*min);
real G2 = 1 ml/(g*min);
real V1 = 0.05 ml/g;
real V2 = 0.10 ml/g;
real Surf = 1 cm^2/g, Ttot = 0.005 umol/cm^2;
real SoV1=Surf/V1;
real SoV2=Surf/V2;
real KdA1 = 10 uM;	
real KdB1 = 10 uM;	
real KdA2 = 10 uM;	
real KdB2 = 10 uM;	
real konA1 = 20 uM^(-1)*s^(-1); 
real konB1 = 20 uM^(-1)*s^(-1); 
real konA2 = 20 uM^(-1)*s^(-1); 
real konB2 = 20 uM^(-1)*s^(-1); 
real kofA1 = KdA1*konA1 ;
real kofB1 = KdB1*konB1 ;
real kofA2 = KdA2*konA2 ;
real kofB2 = KdB2*konB2 ;
real kTA12 = 30 s^(-1);
real kTB12 = 30 s^(-1);
real kTA21 = 30 s^(-1);
real kTB21 = 30 s^(-1);
real kT12 = 50 sec^(-1);
real kT21 = 50 sec^(-1);

// DEPENDENT VARIABLES
real hA1(t) mM; 
real hB1(t) mM; 
real hA2(t) mM; 
real hB2(t) mM; 
real cA1(t) mM; 
real cB1(t) mM; 
real cA2(t) mM; 
real cB2(t) mM; 
real T1(t) umol/cm^2; 
real T2(t) umol/cm^2; 
real T1hA1(t) umol/cm^2;
real T1hB1(t) umol/cm^2;
real T2hA2(t) umol/cm^2;
real T2hB2(t) umol/cm^2;
real T1cA1(t) umol/cm^2;
real T1cB1(t) umol/cm^2;
real T2cA2(t) umol/cm^2;
real T2cB2(t) umol/cm^2;
// INITIAL CONDITIONS
when (t=t.min) {hA1=0; T1hA1=0;}
when (t=t.min) {hB1=0; T1hB1=0;}
when (t=t.min) {hA2=0; T2hA2=0;}
when (t=t.min) {hB2=0; T2hB2=0;}
when (t=t.min) {cA1=0; T1cA1=0;}
when (t=t.min) {cB1=0; T1cB1=0;}
when (t=t.min) {cA2=0; T2cA2=0;}
when (t=t.min) {cB2=0; T2cB2=0;}
when (t=t.min) T1=Ttot/2;
when (t=t.min) T2=Ttot/2;
// ORDINARY DIFFERENTIAL EQUATIONS
hA1:t = Fp/V1*(hA1in-hA1)
      +(-konA1*hA1*T1 + kofA1*T1hA1)*SoV1;
hB1:t = Fp/V1*(hB1in-hB1)
      +(-konB1*hB1*T1 + kofB1*T1hB1)*SoV1;
cA1:t = Fp/V1*(cA1in-cA1)
      +(-konA1*cA1*T1 + kofA1*T1cA1)*SoV1;
cB1:t = Fp/V1*(cB1in-cB1)
      +(-konB1*cB1*T1 + kofB1*T1cB1)*SoV1;
hA2:t = -G2/V2*hA2
      +(-konA2*hA2*T2 + kofA2*T2hA2)*SoV2;
cA2:t = -G2/V2*cA2
      +(-konA2*cA2*T2 + kofA2*T2cA2)*SoV2;
hB2:t = G2/V2*hA2
      +(-konB2*hB2*T2 + kofB2*T2hB2)*SoV2;
cB2:t = G2/V2*cA2
      +(-konB2*cB2*T2 + kofB2*T2cB2)*SoV2;
T1:t = -konA1*hA1*T1 + kofA1*T1hA1 
     -konB1*hB1*T1 + kofB1*T1hB1 
     -konA1*cA1*T1 + kofA1*T1cA1 
     -konB1*cB1*T1 + kofB1*T1cB1 
     - kT12*T1 + kT21*T2;
T1hA1:t = konA1*hA1*T1 - kofA1*T1hA1
        - kTA12*T1hA1 + kTA21*T2hA2;
T1hB1:t = konB1*hB1*T1 - kofB1*T1hB1
        - kTB12*T1hB1 + kTB21*T2hB2;
T2:t = -konA2*hA2*T2 + kofA2*T2hA2 
     -konB2*hB2*T2 + kofB2*T2hB2 
     -konA2*cA2*T2 + kofA2*T2cA2 
     -konB2*cB2*T2 + kofB2*T2cB2 
     +kT12*T1 - kT21*T2;
T2hA2:t = konA2*hA2*T2 - kofA2*T2hA2
        +kTA12*T1hA1 - kTA21*T2hA2;
T2hB2:t = konB2*hB2*T2 - kofB2*T2hB2
        +kTB12*T1hB1 - kTB21*T2hB2;
T1cA1:t = konA1*cA1*T1 - kofA1*T1cA1
        - kTA12*T1cA1 + kTA21*T2cA2;
T1cB1:t = konB1*cB1*T1 - kofB1*T1cB1
        - kTB12*T1cB1 + kTB21*T2cB2;
T2cA2:t = konA2*cA2*T2 - kofA2*T2cA2
        +kTA12*T1cA1 - kTA21*T2cA2;
T2cB2:t = konB2*cB2*T2 - kofB2*T2cB2
        +kTB12*T1cB1 - kTB21*T2cB2;
real TTOT(t) umol/cm^2;
TTOT = T1
     +T2
     +T1hA1
     +T1hB1
     +T2hA2
     +T2hB2
     +T1cA1
     +T1cB1
     +T2cA2
     +T2cB2;
}
// This MML file generated from Trans4.mpc using MPC.
